/* ADSL Header file */

#define VERSION		"1.11 GENTOO EDITION"
#define ROUTE_FILE	"/proc/net/route"
#define STAT_FILE	"/var/run/ppp-mxstream.pid"
#define TRUE 		1
#define FALSE 		0
#define	RETRY		20
#define	SLEEP		1
#define min(a,b)  (((a) < (b)) ? (a) : (b))

int start(int args, char name[10], char arg[5]);
int stop(void);
int restart(int argr, char name[10], char arg[5]);
int version(void);

int hasroute(const char *devicename);
int getdevicename(char *devicename, int maxlen, const char *statfile);
int getpidofconn(char *statfile);
int isadslrunning();
int isadslconnected();
